==> daemonshogi-0.1.3.tar.gz: daemonshogi-0.1.3/src/si/wrapper.c <==
/* SI SHOGI Library
   Copyright (C) 2002 Masahiko Tokita
   This file is part of the SI SHOGI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.w

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with The Daemonshogi; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */
/*
 * wrapper.c
 * $Source: /cvs/si/wrapper.c,v $
 * $Id: wrapper.c,v 1.7 2002/09/17 20:00:22 mik Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include "si.h"
#include "ui.h"
#include "wrapper.h"

FILE *out;

/**
 * 󥹥ȥ饯
 */ 
CSAShogiWrapper *si_wrap_new(void) {
  CSAShogiWrapper *wrapper;

  wrapper = (CSAShogiWrapper *)malloc(sizeof(CSAShogiWrapper));
  if (wrapper == NULL) {
    printf("No enough memory in si_wrap_new().\n");
    abort();
  }

  wrapper->log = fopen("log.txt", "w");
  if (wrapper->log == NULL) {
	  abort();
  }
  out = wrapper->log;

  return wrapper;
}

/** 
 * dispatchѤδؿؤΥݥ󥿤򥻥åȤ
 * @param wrapper 
 * @param f ؿؤΥݥ
 */
void si_wrap_set_dispatch_func(CSAShogiWrapper *wrapper, void (*f)(void)) {
	set_pending_function(f);
}

/**
 * 롣
 * sikou() ƤФ롣
 * @param wrapper
 * @param chudan ǥե饰ؤΥݥ
 */ 
void si_wrap_sikou_ini(CSAShogiWrapper *wrapper, int *chudan) {
  extern GAME g_game;
  extern BOARD g_board;
  extern int flgDisplayMode;
  extern int THINK_DEEP_MAX;

  wrapper->chudan = chudan;
  gmSetChudan(&g_game, chudan);

  boInit(&g_board);
  flgDisplayMode = 0;
  boSetHirate(&g_board);
#ifdef USE_HASH  
  /* ϥåơ֥ */
  newHASH();
#endif /* USE_HASH */
  initGAME(&g_game);

  THINK_DEEP_MAX = 4;

  gmSetInputFunc(&g_game, SENTE, SI_SERIALPORT_1);
  gmSetInputFunc(&g_game, GOTE, SI_COMPUTER_3);

  g_board.point[ 0 ] = grade(&g_board, 0);
  g_board.point[ 1 ] = grade(&g_board, 1);

  boPlayInit(&g_board);
  fputBOARD(wrapper->log, 0, &g_board);
  fflush(wrapper->log);
}

/**
 * ׹ͥ롼sikou() ƤФ롣
 * <pre>
 * return value ϡʲΰ̣
 *
 *               ݡݡ  λ
 *         ݡݡ  i_moto,i_saki,i_naru˻ؤ꤬äƤ롣
 *        ݣ     ݡݡ  ʬԤʣǯ롼
 *        ݣ     ݡݡ  Ԥ    ʣǯ롼
 * </pre>
 * @param wrapper
 * @param tesu      ߤμǣޤ
 *                  ʿ֤ΤȤϡˤʤäƤޤ
 * @param kifu      ޤǤδ
 * @param timer_sec ꡦΤޤǤξ֤ñ̤ޤ
 *                  ׹楫ȥåפϤޤ󤷡åȤƤ⤤ޤ
 *                  
 * @param i_moto    ưɸ(1-81)򥻥åȤޤ
 *                  Ǥľϡ101107ͤ򥻥åȤޤ
 * @param i_saki    ưɸ(1-81)򥻥åȤޤ
 * @param i_naru    1򥻥åȤǤľ0򥻥åȤޤ
 *                  ǤäƤΰưϡ0򥻥åȤޤ
 * @return 
 */ 
int si_wrap_sikou(CSAShogiWrapper *wrapper,
		  int tesu,
		  unsigned char kifu[][2],
		  int* timer_sec,
		  int* i_moto,
		  int* i_saki,
		  int* i_naru) {
  extern BOARD g_board;
  extern TE best_te;
  TE te;
  int ret;
  
    g_board.point[ 0 ] = grade(&g_board, 0);
    g_board.point[ 1 ] = grade(&g_board, 1);

  fflush(wrapper->log);
  if (0 < tesu) {
    int saki = kifu[tesu - 1][0];
    int moto = kifu[tesu - 1][1];
	fprintf(wrapper->log, "tesu : %d\n", tesu);
	fprintf(wrapper->log, "saki : %d\n", saki);
	fprintf(wrapper->log, "moto : %d\n", moto);
    teCSASet(&te, moto, saki);
    boMove(&g_board, &te, ((tesu - 1) % 2));
    g_board.point[ 0 ] = grade(&g_board, 0);
    g_board.point[ 1 ] = grade(&g_board, 1);
	boToggleNext(&g_board); 
	fprintTE(wrapper->log, &te);
  }

  fputBOARD(wrapper->log, 0,&g_board);

  ret = minmax(&g_board);
  fprintf(wrapper->log, "ret : %d\n", ret);
  boMove(&g_board, &best_te, (tesu % 2));
  g_board.point[ 0 ] = grade(&g_board, 0);
  g_board.point[ 1 ] = grade(&g_board, 1);
  boToggleNext(&g_board); 
  fprintTE(wrapper->log, &best_te);

  fputBOARD(wrapper->log, 0, &g_board);

  *i_moto = teCSAimoto(&best_te);
  *i_saki = teCSAisaki(&best_te);
  *i_naru = teCSAinaru(&best_te);

  fflush(wrapper->log);

  if (ret== SI_NORMAL) {
	return 1;
  } else if (ret == SI_TORYO) {
	return 0;
  }
		       
  return -5;
}

/**
 * жɤλȤˡƤФ롣Ԥ
 * void sikou_end() ƤФ롣
 * @param wrapper
 */
void si_wrap_sikou_end(CSAShogiWrapper *wrapper) {
  fflush(wrapper->log);
  fclose(wrapper->log);
#ifdef USE_HASH  
  /* ϥåơ֥ */
  freeHASH();
#endif /* USE_HASH */
}

==> daemonshogi-0.1.4.tar.gz: daemonshogi-0.1.4/src/si/wrapper.c <==
/* SI SHOGI Library
   Copyright (C) 2002 Masahiko Tokita
   This file is part of the SI SHOGI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.w

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with The Daemonshogi; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */
/*
 * wrapper.c
 * $Source: /cvsroot/daemonshogi/daemonshogi/src/si/wrapper.c,v $
 * $Id: wrapper.c,v 1.1.1.1 2005/12/09 09:03:11 tokita Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include "si.h"
#include "ui.h"
#include "wrapper.h"

FILE *out;

/**
 * 󥹥ȥ饯
 */ 
CSAShogiWrapper *si_wrap_new(void) {
  CSAShogiWrapper *wrapper;

  wrapper = (CSAShogiWrapper *)malloc(sizeof(CSAShogiWrapper));
  if (wrapper == NULL) {
    printf("No enough memory in si_wrap_new().\n");
    abort();
  }

  wrapper->log = fopen("log.txt", "w");
  if (wrapper->log == NULL) {
	  abort();
  }
  out = wrapper->log;

  return wrapper;
}

/** 
 * dispatchѤδؿؤΥݥ󥿤򥻥åȤ
 * @param wrapper 
 * @param f ؿؤΥݥ
 */
void si_wrap_set_dispatch_func(CSAShogiWrapper *wrapper, void (*f)(void)) {
	set_pending_function(f);
}

/**
 * 롣
 * sikou() ƤФ롣
 * @param wrapper
 * @param chudan ǥե饰ؤΥݥ
 */ 
void si_wrap_sikou_ini(CSAShogiWrapper *wrapper, int *chudan) {
  extern GAME g_game;
  extern BOARD g_board;
  extern int flgDisplayMode;
  extern int THINK_DEEP_MAX;

  wrapper->chudan = chudan;
  gmSetChudan(&g_game, chudan);

  boInit(&g_board);
  flgDisplayMode = 0;
  boSetHirate(&g_board);
#ifdef USE_HASH  
  /* ϥåơ֥ */
  newHASH();
#endif /* USE_HASH */
  initGAME(&g_game);

  THINK_DEEP_MAX = 4;

  gmSetInputFunc(&g_game, SENTE, SI_SERIALPORT_1);
  gmSetInputFunc(&g_game, GOTE, SI_COMPUTER_3);

  g_board.point[ 0 ] = grade(&g_board, 0);
  g_board.point[ 1 ] = grade(&g_board, 1);

  boPlayInit(&g_board);
  fputBOARD(wrapper->log, 0, &g_board);
  fflush(wrapper->log);
}

/**
 * ׹ͥ롼sikou() ƤФ롣
 * <pre>
 * return value ϡʲΰ̣
 *
 *               ݡݡ  λ
 *         ݡݡ  i_moto,i_saki,i_naru˻ؤ꤬äƤ롣
 *        ݣ     ݡݡ  ʬԤʣǯ롼
 *        ݣ     ݡݡ  Ԥ    ʣǯ롼
 * </pre>
 * @param wrapper
 * @param tesu      ߤμǣޤ
 *                  ʿ֤ΤȤϡˤʤäƤޤ
 * @param kifu      ޤǤδ
 * @param timer_sec ꡦΤޤǤξ֤ñ̤ޤ
 *                  ׹楫ȥåפϤޤ󤷡åȤƤ⤤ޤ
 *                  
 * @param i_moto    ưɸ(1-81)򥻥åȤޤ
 *                  Ǥľϡ101107ͤ򥻥åȤޤ
 * @param i_saki    ưɸ(1-81)򥻥åȤޤ
 * @param i_naru    1򥻥åȤǤľ0򥻥åȤޤ
 *                  ǤäƤΰưϡ0򥻥åȤޤ
 * @return 
 */ 
int si_wrap_sikou(CSAShogiWrapper *wrapper,
		  int tesu,
		  unsigned char kifu[][2],
		  int* timer_sec,
		  int* i_moto,
		  int* i_saki,
		  int* i_naru) {
  extern BOARD g_board;
  extern TE best_te;
  TE te;
  int ret;
  
    g_board.point[ 0 ] = grade(&g_board, 0);
    g_board.point[ 1 ] = grade(&g_board, 1);

  fflush(wrapper->log);
  if (0 < tesu) {
    int saki = kifu[tesu - 1][0];
    int moto = kifu[tesu - 1][1];
	fprintf(wrapper->log, "tesu : %d\n", tesu);
	fprintf(wrapper->log, "saki : %d\n", saki);
	fprintf(wrapper->log, "moto : %d\n", moto);
    teCSASet(&te, moto, saki);
    boMove(&g_board, &te, ((tesu - 1) % 2));
    g_board.point[ 0 ] = grade(&g_board, 0);
    g_board.point[ 1 ] = grade(&g_board, 1);
	boToggleNext(&g_board); 
	fprintTE(wrapper->log, &te);
  }

  fputBOARD(wrapper->log, 0,&g_board);

  ret = minmax(&g_board);
  fprintf(wrapper->log, "ret : %d\n", ret);
  boMove(&g_board, &best_te, (tesu % 2));
  g_board.point[ 0 ] = grade(&g_board, 0);
  g_board.point[ 1 ] = grade(&g_board, 1);
  boToggleNext(&g_board); 
  fprintTE(wrapper->log, &best_te);

  fputBOARD(wrapper->log, 0, &g_board);

  *i_moto = teCSAimoto(&best_te);
  *i_saki = teCSAisaki(&best_te);
  *i_naru = teCSAinaru(&best_te);

  fflush(wrapper->log);

  if (ret== SI_NORMAL) {
	return 1;
  } else if (ret == SI_TORYO) {
	return 0;
  }
		       
  return -5;
}

/**
 * жɤλȤˡƤФ롣Ԥ
 * void sikou_end() ƤФ롣
 * @param wrapper
 */
void si_wrap_sikou_end(CSAShogiWrapper *wrapper) {
  fflush(wrapper->log);
  fclose(wrapper->log);
#ifdef USE_HASH  
  /* ϥåơ֥ */
  freeHASH();
#endif /* USE_HASH */
}
